SequentialBuffer

Struct SequentialBuffer 

pub struct SequentialBuffer<T: Clone + Copy + Default> { /* private fields */ }
A buffer of samples where each channel is stored sequentially in memory.

T is the backing type of the storage, typically f32.

The number of frames and number of channels cannot be changed once constructed.

Implementations

Source

impl<T: Clone + Copy + Default> SequentialBuffer<T>

pub fn new(channels: NonZeroUsize, frames: usize) -> Self

pub fn frames(&self) -> usize

pub fn num_channels(&self) -> NonZeroUsize

pub fn channel_slice(&self, channel: usize) -> Option<&[T]>

Returns an immutable slice of the given channel. This slice will have a length of self.frames().

Returns None if channel >= self.num_channels().

pub fn channel_slice_mut(&mut self, channel: usize) -> Option<&mut [T]>

Returns a mutable slice to the given channel. This slice will have a length of self.frames().

Returns None if channel >= self.num_channels().

pub fn stereo(&self, frames: usize) -> Option<(&[T], &[T])>

Returns two immutable slices to the first two channels in this buffer with length frames.

Clamps frames to the available data.

If the number of channels in this buffer is less than 2, then this will return None.

pub fn stereo_mut(&mut self, frames: usize) -> Option<(&mut [T], &mut [T])>

Returns two mutable slices to the first two channels in this buffer with length frames.

Clamps frames to the available data.

If the number of channels in this buffer is less than 2, then this will return None.

pub fn channels<const MAX_CHANNELS: usize>( &self, num_channels: usize, frames: usize, ) -> ArrayVec<&[T], MAX_CHANNELS>

Returns a vec of slices to the first frames frames of the backing buffers for the first num_channels channels present.

Clamps num_channels and frames to the available data.

pub fn channels_mut<const MAX_CHANNELS: usize>( &mut self, num_channels: usize, frames: usize, ) -> ArrayVec<&mut [T], MAX_CHANNELS>

Returns a vec of mutable slices to the first frames frames of the backing buffers for the first num_channels channels present.

Clamps num_channels and frames to the available data.

pub fn iter_channels(&self) -> impl Iterator<Item = &[T]>

Iterate over all the channels immutably. Each channel slice will have a length of self.frames().

pub fn iter_channels_mut(&mut self) -> impl Iterator<Item = &mut [T]>

Iterate over all the channels mutably. Each channel slice will have a length of self.frames().