pub struct StreamInfo {
pub sample_rate: NonZeroU32,
pub sample_rate_recip: f64,
pub prev_sample_rate: NonZeroU32,
pub max_block_frames: NonZeroU32,
pub num_stream_in_channels: u32,
pub num_stream_out_channels: u32,
pub input_to_output_latency_seconds: f64,
pub declick_frames: NonZeroU32,
pub output_device_id: String,
pub input_device_id: Option<String>,
}Expand description
Information about a running audio stream.
Fields
sample_rate: NonZeroU32The sample rate of the audio stream.
sample_rate_recip: f64The reciprocal of the sample rate.
This is provided for convenience since dividing by the sample rate is such a common operation.
Note to users implementing a custom AudioBackend: The context will overwrite
this value, so just set this to the default value.
prev_sample_rate: NonZeroU32The sample rate of the previous stream. (If this is the first stream, then this
will just be a copy of StreamInfo::sample_rate).
Note to users implementing a custom AudioBackend: The context will overwrite
this value, so just set this to the default value.
max_block_frames: NonZeroU32The maximum number of frames that can appear in a single process cyle.
num_stream_in_channels: u32The number of input audio channels in the stream.
num_stream_out_channels: u32The number of output audio channels in the stream.
input_to_output_latency_seconds: f64The latency of the input to output stream in seconds.
declick_frames: NonZeroU32The number of frames used in the shared declicker DSP.
Note to users implementing a custom AudioBackend: The context will overwrite
this value, so just set this to the default value.
output_device_id: StringThe identifier of the output audio device (converted to a string).
input_device_id: Option<String>The identifier of the input audio device (converted to a string).