pub struct ConstSequentialBuffer<T: Clone + Copy + Default, const CHANNELS: usize> { /* private fields */ }Expand description
A memory-efficient buffer of samples with CHANNELS channels. Each channel
has a length of frames.
T is the backing type of the storage, typically f32.
This is like a SequentialBuffer but guarantees all MAX_CHANNELS are present.
The number of frames and number of channels cannot be changed once constructed.
Implementations
Sourceimpl<T: Clone + Copy + Default, const CHANNELS: usize> ConstSequentialBuffer<T, CHANNELS>
impl<T: Clone + Copy + Default, const CHANNELS: usize> ConstSequentialBuffer<T, CHANNELS>
pub const fn empty() -> Self
pub fn new(frames: usize) -> Self
pub fn frames(&self) -> usize
Sourcepub fn first_with_frames(&self, frames: usize) -> &[T]
pub fn first_with_frames(&self, frames: usize) -> &[T]
Get an immutable reference to the first channel with the given number of frames.
The length of the returned slice will be either frames or the number of
frames in this buffer, whichever is smaller.
Sourcepub fn first_with_frames_mut(&mut self, frames: usize) -> &mut [T]
pub fn first_with_frames_mut(&mut self, frames: usize) -> &mut [T]
Get a mutable reference to the first channel with the given number of frames.
The length of the returned slice will be either frames or the number of
frames in this buffer, whichever is smaller.
Sourcepub fn channels<const NUM_CHANNELS: usize>(&self) -> [&[T]; NUM_CHANNELS]
pub fn channels<const NUM_CHANNELS: usize>(&self) -> [&[T]; NUM_CHANNELS]
Get an immutable reference to the first given number of channels in this buffer.
Panics
Panics if NUM_CHANNELS > Self::CHANNELS
Sourcepub fn channels_mut<const NUM_CHANNELS: usize>(
&mut self,
) -> [&mut [T]; NUM_CHANNELS]
pub fn channels_mut<const NUM_CHANNELS: usize>( &mut self, ) -> [&mut [T]; NUM_CHANNELS]
Get a mutable reference to the first given number of channels in this buffer.
Panics
Panics if NUM_CHANNELS > Self::CHANNELS
Sourcepub fn channels_with_frames<const NUM_CHANNELS: usize>(
&self,
frames: usize,
) -> [&[T]; NUM_CHANNELS]
pub fn channels_with_frames<const NUM_CHANNELS: usize>( &self, frames: usize, ) -> [&[T]; NUM_CHANNELS]
Get an immutable reference to the first given number of channels with the given number of frames.
The length of the returned slices will be either frames or the number of
frames in this buffer, whichever is smaller.
Panics
Panics if NUM_CHANNELS > Self::CHANNELS
Sourcepub fn channels_with_frames_mut<const NUM_CHANNELS: usize>(
&mut self,
frames: usize,
) -> [&mut [T]; NUM_CHANNELS]
pub fn channels_with_frames_mut<const NUM_CHANNELS: usize>( &mut self, frames: usize, ) -> [&mut [T]; NUM_CHANNELS]
Get a mutable reference to the first given number of channels with the given number of frames.
The length of the returned slices will be either frames or the number of
frames in this buffer, whichever is smaller.
Panics
Panics if NUM_CHANNELS > Self::CHANNELS
Sourcepub fn all(&self) -> [&[T]; CHANNELS]
pub fn all(&self) -> [&[T]; CHANNELS]
Get an immutable reference to all channels in this buffer.
Sourcepub fn all_mut(&mut self) -> [&mut [T]; CHANNELS]
pub fn all_mut(&mut self) -> [&mut [T]; CHANNELS]
Get a mutable reference to all channels in this buffer.
Sourcepub fn all_with_frames(&self, frames: usize) -> [&[T]; CHANNELS]
pub fn all_with_frames(&self, frames: usize) -> [&[T]; CHANNELS]
Get an immutable reference to all channels with the given number of frames.
The length of the returned slices will be either frames or the number of
frames in this buffer, whichever is smaller.
Sourcepub fn all_with_frames_mut(&mut self, frames: usize) -> [&mut [T]; CHANNELS]
pub fn all_with_frames_mut(&mut self, frames: usize) -> [&mut [T]; CHANNELS]
Get a mutable reference to all channels with the given number of frames.
The length of the returned slices will be either frames or the number of
frames in this buffer, whichever is smaller.
Sourcepub fn iter_channels(&self) -> impl Iterator<Item = &[T]>
pub fn iter_channels(&self) -> impl Iterator<Item = &[T]>
Iterate over all the channels immutably. Each channel slice will have a length
of self.frames().
Sourcepub fn iter_channels_mut(&mut self) -> impl Iterator<Item = &mut [T]>
pub fn iter_channels_mut(&mut self) -> impl Iterator<Item = &mut [T]>
Iterate over all the channels mutably. Each channel slice will have a length
of self.frames().