pub struct InstanceBuffer<T: Clone + Copy + Default> { /* private fields */ }Expand description
A memory-efficient buffer of samples with a given number of instances each with a given
number of channels. Each channel has a length of frames.
T is the backing type of the storage, typically f32.
This is like a collection of num_instances SequentialBuffers but contiguous in memory.
The number of instances, channels, and frames cannot be changed once constructed.
Implementations
Sourceimpl<T: Clone + Copy + Default> InstanceBuffer<T>
impl<T: Clone + Copy + Default> InstanceBuffer<T>
pub fn new(instances: usize, channels: NonZeroUsize, frames: usize) -> Self
pub fn frames(&self) -> usize
pub fn num_channels(&self) -> NonZeroUsize
pub fn num_instances(&self) -> usize
Sourcepub fn instance<const MAX_CHANNELS: usize>(
&self,
instance_index: usize,
channels: usize,
frames: usize,
) -> Option<ArrayVec<&[T], MAX_CHANNELS>>
pub fn instance<const MAX_CHANNELS: usize>( &self, instance_index: usize, channels: usize, frames: usize, ) -> Option<ArrayVec<&[T], MAX_CHANNELS>>
Returns an array of slices to the first frames frames of the backing buffers
for the first num_channels channels present of the instance at instance_index.
Clamps num_channels and frames to the available data.
Returns None if there is no instance at instance_index.
Sourcepub fn instance_mut<const MAX_CHANNELS: usize>(
&mut self,
instance_index: usize,
channels: usize,
frames: usize,
) -> Option<ArrayVec<&mut [T], MAX_CHANNELS>>
pub fn instance_mut<const MAX_CHANNELS: usize>( &mut self, instance_index: usize, channels: usize, frames: usize, ) -> Option<ArrayVec<&mut [T], MAX_CHANNELS>>
Returns an array of mutable slices to the first frames frames of the backing buffers
for the first num_channels channels present of the instance at instance_index.
Clamps num_channels and frames to the available data.
Returns None if there is no instance at instance_index.